# buildforkernels macro hint: when you build a new version or a new release
# that contains bugfixes or other improvements then you must disable the
# "buildforkernels newest" macro for just that build; immediately after
# queuing that build enable the macro again for subsequent builds; that way
# a new akmod package will only get build when a new one is actually needed

# %define buildforkernels newest
%define buildforkernels current

%define tname open-vm-tools
%define VER		9.4.3
%define buildver	1328054
%define	DATE		2013.09.16
%define ovtmodules vmhgfs vmblock

Name:		open-vm-tools-kmod
Version:	%{VER}.%{buildver}
Release:	1.9%{?dist}
Summary:	VMware Tools Kernel Modules
Group:		System Environment/Kernel
License:	GPLv2-42
URL:		http://open-vm-tools.sourceforge.net/
Source0:	http://downloads.sourceforge.net/%{tname}/%{tname}-%{DATE}-%{buildver}.tar.gz
Source11:	%{tname}-excludekernel-filterfile
Source1:	mount.vmhgfs-%{fedora}-%{_arch}
Patch1:		%{tname}-%{DATE}-%{buildver}-patch-001
Patch2:		vmblock.3.10.patch
%if 0%{?fedora} >= 19
Patch3:		vmblock.3.11.patch
%endif
BuildRoot:	%{_tmppath}/%{name}-%{VER}-%{release}-root-%(%{__id_u} -n)
Provides:	%{name}-common

# VMWare only supports x86 architectures.
ExclusiveArch:  %{ix86} x86_64
# ExclusiveArch:  i686 x86_64

# get the needed BuildRequires (in parts depending on what we build for)
BuildRequires:  %{_bindir}/kmodtool
%{!?kernels:BuildRequires: buildsys-build-rpmfusion-kerneldevpkgs-%{?buildforkernels:%{buildforkernels}}%{!?buildforkernels:current}-%{_target_cpu} }
# kmodtool does its magic here
%{expand:%(kmodtool --target %{_target_cpu} --repo rpmfusion --kmodname %{name} --filterfile %{SOURCE11} %{?buildforkernels:--%{buildforkernels}} %{?kernels:--for-kernels "%{?kernels}"} 2>/dev/null) }

%description
Open-vm-tools are the open source implementation of VMware Tools. They
are a set of guest operating system virtualization components that
enhance performance and user experience of VMWare virtual
machines. This package contains the kernel modules of open-vm-tools.


%prep
# error out if there was something wrong with kmodtool
%{?kmodtool_check}
# print kmodtool output for debugging purposes:
kmodtool  --target %{_target_cpu}  --repo rpmfusion --kmodname %{name} --filterfile %{SOURCE11} %{?buildforkernels:--%{buildforkernels}} %{?kernels:--for-kernels "%{?kernels}"} 2>/dev/null

%setup -q -n open-vm-tools-%{DATE}-%{buildver}
%patch1 -p1
%patch2 -p0
%if 0%{?fedora} >= 19
%patch3 -p0
%endif

for kernel_version  in %{?kernel_versions} ; do
    mkdir -p _kmod_build_${kernel_version%%___*}/
    cp -ar modules _kmod_build_${kernel_version%%___*}/
    cp -ar lib _kmod_build_${kernel_version%%___*}/
done


%build
for kernel_version  in %{?kernel_versions} ; do
    for ovtmodule in %{ovtmodules}; do
        make -C ${PWD}/_kmod_build_${kernel_version%%___*}/modules/linux/${ovtmodule} VM_UNAME=${kernel_version%%___*} HEADER_DIR="${kernel_version##*___}/include" OVT_SOURCE_DIR=${PWD}/_kmod_build_${kernel_version%%___*} CC_OPTS='-DVMW_HAVE_EPOLL -Wno-error=unused-local-typedefs -Wno-error=implicit-function-declaration'
    done
done


%install
rm -rf $RPM_BUILD_ROOT
for kernel_version  in %{?kernel_versions} ; do
    for ovtmodule in %{ovtmodules}; do
        install -D -m 755 _kmod_build_${kernel_version%%___*}/modules/linux/${ovtmodule}/${ovtmodule}.ko $RPM_BUILD_ROOT%{kmodinstdir_prefix}/${kernel_version%%___*}/%{kmodinstdir_postfix}/${ovtmodule}.ko
    done
done
# akmods:
%{?akmod_install}

%{__mkdir_p} %{buildroot}/%{_sysconfdir}/modules-load.d
cat >> %{buildroot}/%{_sysconfdir}/modules-load.d/%{name}.conf <<EOF
vmw_vmci
vmhgfs
vmblock
EOF

%{__mkdir_p} %{buildroot}/%{_sbindir}
cp -p %{SOURCE1} %{buildroot}/%{_sbindir}/mount.vmhgfs

%clean
rm -rf $RPM_BUILD_ROOT

%files
%attr(0644, root, root)	%{_sysconfdir}/modules-load.d/%{name}.conf
%attr(0755, root, root)	%{_sbindir}/mount.vmhgfs

%changelog
* Mon Nov 25 2013 Lawrence Rogers < lrr@cert.org > - 9.4.3-1328054-1.9
- Rebuild for kernel 3.11.9-200

* Mon Nov 18 2013 Lawrence Rogers < lrr@cert.org > - 9.4.3-1328054-1.8
- Rebuild for kernel 3.11.8-200

* Fri Nov 08 2013 Lawrence Rogers < lrr@cert.org > - 9.4.3-1328054-1.7
- Rebuild for kernel 3.11.7-200

* Tue Nov 05 2013 Lawrence Rogers < lrr@cert.org > - 9.4.3-1328054-1.6
- Rebuild for kernel 3.11.6-201

* Tue Oct 29 2013 Lawrence Rogers < lrr@cert.org > - 9.4.3-1328054-1.5
- Rebuild for kernel 3.11.6-200

* Tue Oct 29 2013 Lawrence Rogers < lrr@cert.org > - 9.4.3-1328054-1.4
- Rebuild for kernel 3.11.4-201

* Mon Oct 07 2013 Lawrence Rogers < lrr@cert.org > - 9.4.3-1328054-1.3
- Rebuild for kernel 3.11.3-201

* Fri Oct 04 2013 Lawrence Rogers < lrr@cert.org > - 9.4.3-1328054-1.2
- Rebuild for kernel 3.11.2-200

* Fri Oct 04 2013 Lawrence Rogers < lrr@cert.org > - 9.4.3-1328054-1.1
- Rebuild for kernel 3.11.1-200
